@@ -1,8 +1,9 @@
 package Test::More;
 
-use 5.004;
+use 5.006;
 
 use strict;
+use warnings;
 
 # Can't use Carp because it might cause use_ok() to accidentally succeed
 # even though the module being used forgot to use Carp.  Yes, this
@@ -12,12 +13,11 @@ sub _carp {
     warn @_, " at $file line $line\n";
 }
 
-use vars qw($VERSION @ISA @EXPORT %EXPORT_TAGS $TODO);
-$VERSION = '0.72';
+our (@EXPORT, %EXPORT_TAGS, $TODO);
+our $VERSION = '0.72';
 $VERSION = eval $VERSION;    # make the alpha version come out as a number
 
-use Test::Builder::Module;
-@ISA    = qw(Test::Builder::Module);
+use base qw(Test::Builder::Module);
 @EXPORT = qw(ok use_ok require_ok
   is isnt like unlike is_deeply
   cmp_ok
@@ -444,7 +444,7 @@ quickly testing an interface.
 No matter how many @methods you check, a single can_ok() call counts
 as one test.  If you desire otherwise, use:
 
-    foreach my $meth (@methods) {
+    for my $meth (@methods) {
         can_ok('Foo', $meth);
     }
 
@@ -468,7 +468,7 @@ sub can_ok ($@) {
     }
 
     my @nok = ();
-    foreach my $method (@methods) {
+    for my $method (@methods) {
         $tb->_try( sub { $proto->can($method) } ) or push @nok, $method;
     }
 
@@ -771,7 +771,7 @@ along these lines.
 
 =cut
 
-use vars qw(@Data_Stack %Refs_Seen);
+our (@Data_Stack, %Refs_Seen);
 my $DNE = bless [], 'Does::Not::Exist';
 
 sub _dne {
@@ -825,7 +825,7 @@ sub _format_stack {
 
     my $var       = '$FOO';
     my $did_arrow = 0;
-    foreach my $entry (@Stack) {
+    for my $entry (@Stack) {
         my $type = $entry->{type} || '';
         my $idx = $entry->{'idx'};
         if ( $type eq 'HASH' ) {
@@ -847,7 +847,7 @@ sub _format_stack {
     ( $vars[1] = $var ) =~ s/\$FOO/\$expected/;
 
     my $out = "Structures begin differing at:\n";
-    foreach my $idx ( 0 .. $#vals ) {
+    for my $idx ( 0 .. $#vals ) {
         my $val = $vals[$idx];
         $vals[$idx]
           = !defined $val ? 'undef'
@@ -1007,7 +1007,7 @@ sub skip {
         $tb->skip($why);
     }
 
-    local $^W = 0;
+    no warnings 'exiting';
     last SKIP;
 }
 
@@ -1088,7 +1088,7 @@ sub todo_skip {
         $tb->todo_skip($why);
     }
 
-    local $^W = 0;
+    no warnings 'exiting';
     last TODO;
 }
 
@@ -1212,7 +1212,7 @@ sub _deep_check {
     {
 
         # Quiet uninitialized value warnings when comparing undefs.
-        local $^W = 0;
+        no warnings 'uninitialized';
 
         $tb->_unoverload_str( \$e1, \$e2 );
 
@@ -1313,7 +1313,7 @@ sub _eq_hash {
 
     my $ok = 1;
     my $bigger = keys %$a1 > keys %$a2 ? $a1 : $a2;
-    foreach my $k ( keys %$bigger ) {
+    for my $k ( keys %$bigger ) {
         my $e1 = exists $a1->{$k} ? $a1->{$k} : $DNE;
         my $e2 = exists $a2->{$k} ? $a2->{$k} : $DNE;
 
@@ -1358,7 +1358,7 @@ sub eq_set {
     return 0 unless @$a1 == @$a2;
 
     # There's faster ways to do this, but this is easiest.
-    local $^W = 0;
+    no warnings 'uninitialized';
 
     # It really doesn't matter how we sort them, as long as both arrays are
     # sorted with the same algorithm.
